@@ -46,9 +46,10 @@ Mutex SQLDatabase::locker;
 SQLDatabase::SQLDatabase(ScriptImage *img, Line *line) :
 ScriptObject(img)
 {
+	char buffer[256];
         long err;
-        SQLCHAR stat[10];
-        SQLSMALLINT mlen;
+
+	ScriptCommand *cmd = img->getCommand();
 
 	name = ScriptCommand::findKeyword(line, "database");
 	user = ScriptCommand::findKeyword(line, "user");
@@ -88,13 +89,17 @@ ScriptObject(img)
         {
         	SQLFreeHandle(SQL_HANDLE_DBC, hdbc);
                 hdbc = NULL;
+		snprintf(buffer, sizeof(buffer), "%s: connection failed", name);
+		cmd->errlog("error", buffer);
 		slog.debug("odbc: database '%s' failed connect; serial=%ld",
 			name, instance);
 		return;
 	}
 
+	snprintf(buffer, sizeof(buffer), "%s: database connected", name);
         slog.debug("odbc: database '%s' active; serial=%ld",
                 name, instance);
+	cmd->errlog("notice", buffer);
 }
 
 SQLDatabase::~SQLDatabase()
