@@ -439,6 +439,8 @@ void ScriptInterp::trap(unsigned id)
 	clearStack();
 	frame[stack].tranflag = frame[stack].caseflag = false;
 	frame[stack].line = frame[stack].first = trap;
+	if(!id)
+		exiting = true;
 }
 
 bool ScriptInterp::pull(void)      
@@ -1130,6 +1132,9 @@ bool ScriptInterp::exit(void)
 		return false;
 
 	exiting = true;
+	trap((unsigned)0);
+	if(frame[stack].line)
+		return true;
 	return redirect("::exit");
 }
 
@@ -1146,6 +1151,11 @@ bool ScriptInterp::signal(const char *trapname)
 
 	mask &= line->mask;
 	mask &= frame[stack].mask;
+	if(frame[stack].line)
+		mask &= frame[stack].line->mask;
+	
+	if(exiting)
+		mask &= ~1;
 
 	if(!mask)
 		return false;
@@ -1165,6 +1175,9 @@ bool ScriptInterp::signal(unsigned id)
 	if(!image)
 		return true;
 
+	if(!id && exiting)
+		return false;
+
 	MutexLock lock(*this);
 
 	if(id >= TRAP_BITS)
@@ -1172,12 +1185,14 @@ bool ScriptInterp::signal(unsigned id)
 
 	cmask = mask = cmd->getTrapMask(id);
 	mask &= frame[stack].mask;
-	mask &= frame[stack].line->mask;
+	if(frame[stack].line)
+		mask &= frame[stack].line->mask;
 
 	if(!mask)
 		return false;
 
 //	stop(mask);
+
 	trap(id);
 
 	image->fastBranch(this);
@@ -1434,6 +1449,9 @@ void ScriptInterp::logmissing(const char *sym, const char *reason, const char *g
         if(*sym == '@' || *sym == '%' || *sym == '&')
                 ++sym;
 
+	if(!frame[stack].line)
+		return;
+
         slog.warn() << logname << ": " << frame[stack].script->filename
                 << "(" << frame[stack].line->lnum << "): " << group << " "
                 << sym << " " << reason << endl;
