@@ -105,7 +105,7 @@ ScriptRegistry::ScriptRegistry()
         char *env;
 
         Script::plugins = 
-		"C:/Program Files/Common Files/CAPE Framework/Script Plugins";
+		"C:/Program Files/Common Files/GNU Telephony/Script Plugins";
 
 #ifdef	DEBUG
 #define	PLUGINS "Debug"
